part of 'custom_skin_bloc.dart';

@immutable
sealed class CustomSkinEvent {}

class SkinVisibilityChanged extends CustomSkinEvent {
  SkinVisibilityChanged();
}

class ValueChanged extends CustomSkinEvent {
  final bool isPlaying;
  final double duration;
  final double time;

  ValueChanged(this.isPlaying, this.duration, this.time);
}

class PlaybackChanged extends CustomSkinEvent {
  PlaybackChanged();
}

class CurrentPositionChanged extends CustomSkinEvent {
  final double time;
  CurrentPositionChanged(this.time);
}

class PlayerSeekBackEvent extends CustomSkinEvent {
  PlayerSeekBackEvent();
}

class PlayerSeekForwardEvent extends CustomSkinEvent {
  PlayerSeekForwardEvent();
}

class PlayerSeekEvent extends CustomSkinEvent {
  final double time;
  PlayerSeekEvent(this.time);
}